@@ -6,16 +6,16 @@ OC.L10N.register(
     "Personal" : "Pribadi",
     "Later" : "Nanti",
     "Mail" : "Surel",
+    "Connecting" : "Menyambungkan",
+    "Save" : "Simpan",
+    "Connect" : "Sambungkan",
+    "Password required" : "Kata sandi diperlukan",
     "Name" : "Nama",
     "Password" : "Kata kunci",
     "None" : "Tidak ada",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "SMTP Password" : "Kata sandi SMTP",
-    "Connecting" : "Menyambungkan",
-    "Save" : "Simpan",
-    "Connect" : "Sambungkan",
-    "Password required" : "Kata sandi diperlukan",
     "Signature" : "Tanda",
     "Go back" : "Kembali",
     "Email address" : "Alamat surel",
@@ -24,6 +24,7 @@ OC.L10N.register(
     "General" : "Umum",
     "List" : "Daftar",
     "Register" : "Daftar",
+    "About" : "Tentang",
     "Keyboard shortcuts" : "Pintasan keyboard",
     "Archive" : "Arsip",
     "Delete" : "Hapus",
@@ -32,8 +33,8 @@ OC.L10N.register(
     "Refresh" : "Segarkan",
     "Subject" : "Subjek",
     "Upload attachment" : "Unggah lampiran",
-    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Choose" : "Pilih",
+    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Confirm" : "Konfirmasi",
     "Favorite" : "Favorit",
     "Read" : "Baca",
@@ -51,35 +52,36 @@ OC.L10N.register(
     "email" : "surel",
     "Other" : "Lainnya",
     "Forward" : "Teruskan",
+    "Translate" : "Terjemahkan",
     "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
     "Import into calendar" : "Impor ke kalender",
     "Download attachment" : "Unduh lampiran",
     "Move" : "Pindah",
+    "Remove account" : "Hapus akun",
     "Quota" : "Kuota",
     "Saving" : "Menyimpan",
-    "Remove account" : "Hapus akun",
     "Mark all as read" : "Tandai semua telah dibaca",
     "Rename" : "Ubah nama",
     "Clear cache" : "Bersihkan cache",
     "New message" : "Pesan baru",
-    "Retry" : "Ulangi",
-    "Sending …" : "Mengirim ...",
     "Draft" : "Draf",
     "Reply" : "Balas",
+    "Retry" : "Ulangi",
+    "Sending …" : "Mengirim ...",
     "Message" : "Pesan",
     "Copy to clipboard" : "Salin ke papan klip",
     "Add" : "Masukkan",
+    "Clear" : "Bersihkan",
     "Close" : "Tutup",
     "Date" : "Date",
     "Tags" : "Tag",
-    "Clear" : "Bersihkan",
-    "Add tag" : "Tambahkan tag",
     "Tag already exists" : "Tag sudah ada",
+    "Add tag" : "Tambahkan tag",
     "Unsubscribe" : "Berhenti berlangganan",
     "Mark as unread" : "Tandai belum dibaca",
     "Mark as read" : "tandai sudah dibaca",
-    "(organizer)" : "(penyelenggara)",
     "Untitled event" : "Acara tanpa judul",
+    "(organizer)" : "(penyelenggara)",
     "Operator" : "Operator",
     "Actions" : "Tindakan",
     "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
@@ -105,7 +107,6 @@ OC.L10N.register(
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
     "Forwarding to %s" : "Teruskan ke %s",
     "Redirect" : "Mengalihkan",
-    "Continue to %s" : "Lanjutkan ke %s",
-    "Unselect" : "Batal pilih"
+    "Continue to %s" : "Lanjutkan ke %s"
 },
 "nplurals=1; plural=0;");
