@@ -5,15 +5,15 @@ OC.L10N.register(
     "Work" : "ที่ทำงาน",
     "Personal" : "ส่วนตัว",
     "Mail" : "จดหมาย",
+    "Connecting" : "กำลังเชื่อมต่อ",
+    "Save" : "บันทึก",
+    "Connect" : "เชื่อมต่อ",
     "Name" : "ชื่อ",
     "Password" : "รหัสผ่าน",
     "None" : "ไม่มี",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "SMTP Password" : "รหัสผ่าน SMTP",
-    "Connecting" : "กำลังเชื่อมต่อ",
-    "Save" : "บันทึก",
-    "Connect" : "เชื่อมต่อ",
     "Signature" : "ลายเซ็น",
     "Go back" : "กลับไป",
     "Change name" : "เปลี่ยนชื่อ",
@@ -22,14 +22,15 @@ OC.L10N.register(
     "Accounts" : "บัญชี",
     "General" : "ทั่วไป",
     "Register" : "ลงทะเบียน",
+    "About" : "เกี่ยวกับ",
     "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Archive" : "ที่เก็บถาวร",
     "Delete" : "ลบ",
     "Search" : "ค้นหา",
     "Send" : "ส่ง",
     "Refresh" : "รีเฟรช",
-    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Choose" : "เลือก",
+    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Confirm" : "ยืนยัน",
     "Favorite" : "รายการโปรด",
     "Read" : "อ่าน",
@@ -44,25 +45,26 @@ OC.L10N.register(
     "Remove" : "ลบออก",
     "Other" : "อื่น ๆ",
     "Forward" : "ส่งต่อ",
-    "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บไฟล์แนบลงไป",
+    "Translate" : "แปลภาษา",
     "Unnamed" : "ไม่มีชื่อ",
+    "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บไฟล์แนบลงไป",
     "Move" : "ย้าย",
     "Moving" : "กำลังย้าย",
+    "Remove account" : "ลบบัญชี",
     "Quota" : "โควต้า",
     "Saving" : "กำลังบันทึก",
-    "Remove account" : "ลบบัญชี",
     "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
     "Rename" : "เปลี่ยนชื่อ",
     "Clear cache" : "ล้างแคช",
-    "Sending …" : "กำลังส่ง ...",
     "Reply" : "ตอบกลับ",
+    "Sending …" : "กำลังส่ง ...",
     "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
     "Add" : "เพิ่ม",
+    "Clear" : "ล้าง",
     "Close" : "ปิด",
     "Date" : "วันที่",
     "Tags" : "แท็ก",
     "Last 7 days" : "ภายใน 7 วัน",
-    "Clear" : "ล้าง",
     "Custom" : "กำหนดเอง",
     "Tag already exists" : "มีแท็กอยู่แล้ว",
     "Not found" : "ไม่พบ",
@@ -90,7 +92,6 @@ OC.L10N.register(
     "Error loading message" : "เกิดข้อผิดพลาดขณะโหลดข้อความ",
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
-    "Continue to %s" : "ดำเนินการต่อไปที่ %s",
-    "Unselect" : "ยกเลิกการเลือก"
+    "Continue to %s" : "ดำเนินการต่อไปที่ %s"
 },
 "nplurals=1; plural=0;");
